#!/bin/sh
# sm_install_saphana.sh 1.2 11.09.2014i PLE
# Copyright  : (c)2014 SEP AG GmbH D83629 Weyarn, all rights reserved
# This script can be used 
# to easily install the SAP HANA Database extension
# for SEP sesam on a standard environment.

# Read pathes from Sesam installation
read_ini ()
{
   SM_INI=`grep -i ^sm_ini /etc/sesam2000.ini|cut -d"=" -f2`
   if [  $SM_INI ]
   then
     echo `grep -i $1 $SM_INI|cut -d"=" -f2`
   fi
}

if [ -r /etc/sesam2000.ini ]
  then
    ini_dir=`read_ini gv_rw_ini=`
    bin_dir=`read_ini gv_ro_bin`
    lgc_dir=`read_ini gv_rw_lgc`
    skel_dir=`read_ini gv_ro=`skel
  fi

# Print some information for the customer
read -p "Welcome to the SAP HANA Database extension installation script for SEP sesam. This script assumes that the HANA instance has been set up meeting the recommendations from the SAP HANA Administration guide. If you made a custom installation that doesn't use /usr/sap/<SID> pathes, please press Ctrl+C now and install manually."
#
# Determine the system SID and write it to variable
#
db_sidpath=`ls -d /usr/sap/*/ | head -n 1`
read -p "The detected path to your SID directory is $db_sidpath - if this is correct, please press any key to install. If not, press Ctrl+C to abort."

# Create directories needed for hdbbackint binary and parameter file
echo "Creating directories for hdbbackint binary and parameter file..."
mkdir -p $db_sidpath/SYS/global/hdb/opt/hdbconfig

# Copy the parameter file template from skel/templates to hdbconfig
echo "Copying backint parameter file to /var/opt/sesam/var/ini..."
cp $skel_dir/templates/backint_saphana.utl $ini_dir

# Set the permissions for the logging dir
echo "Setting permission 777 on sesam log/lgc directory..."
chmod 777 $lgc_dir

# Create symlinks
echo "Creating symlinks for hdbbackint and the parameter file"
ln -s $bin_dir/hdbbackint $db_sidpath/SYS/global/hdb/opt/hdbbackint
ln -s $ini_dir/backint_saphana.utl $db_sidpath/SYS/global/hdb/opt/hdbconfig

echo "##############  FINISHED  ###################"
echo "Please note: If you are running a clustered SAP HANA DB, remember to run this script on every node of the cluster. Also don't forget to adjust the /var/opt/sesam/var/ini/backint_saphana.utl files accordingly on every node. Have fun making backups!"

